@@ -231,8 +231,7 @@
     <message>
         <location filename="config_dialog.ui" line="1272"/>
         <source>Clear all sync data in Google servers. To delete data completely, make sure there is no other machine which is running sync and stop sync on this machine after clearing the data.</source>
-        <translation>同期サーバーにあるデータを全て消去します。データを消去したままにするには、他のコンピュータで実行している同期をあらかじめ解除し、消去の実行後にこのコンピュータの同期も解除してください。
-実行しますか？</translation>
+        <translation>同期サーバーにあるデータを全て消去します。データを消去したままにするには、他のコンピュータで実行している同期をあらかじめ解除し、消去の実行後にこのコンピュータの同期も解除してください。</translation>
     </message>
     <message>
         <location filename="config_dialog.ui" line="57"/>
@@ -540,12 +539,12 @@
         <translation>最終同期時刻</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1310"/>
+        <location filename="config_dialog.ui" line="1355"/>
         <source>Misc</source>
         <translation>その他</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1357"/>
+        <location filename="config_dialog.ui" line="1402"/>
         <source>Logging level (debug only)</source>
         <translation>ログレベル（デバッグ）</translation>
     </message>
@@ -554,23 +553,23 @@
         <translation type="obsolete">プロトコル ログを有効にする（デバッグ）</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1386"/>
+        <location filename="config_dialog.ui" line="1431"/>
         <source>Logging</source>
         <translation>ログ</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1418"/>
+        <location filename="config_dialog.ui" line="1463"/>
         <source>Administration</source>
         <translation>管理</translation>
     </message>
     <message>
         <location filename="config_dialog.ui" line="1113"/>
-        <location filename="config_dialog.ui" line="1456"/>
+        <location filename="config_dialog.ui" line="1501"/>
         <source>Settings...</source>
         <translation>設定変更...</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1476"/>
+        <location filename="config_dialog.ui" line="1521"/>
         <source>Dictionary preloading and UAC settings</source>
         <translation>オンメモリ辞書とUACの設定</translation>
     </message>
@@ -600,22 +599,32 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
         <translation>設定や同期用ユーザー辞書を、異なるコンピュータ間で安全に同期します</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1501"/>
+        <location filename="config_dialog.ui" line="1317"/>
+        <source>Allow Using Cloud Handwriting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config_dialog.ui" line="1333"/>
+        <source>Cloud servers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config_dialog.ui" line="1546"/>
         <source>Check if Mozc is the default IME on startup</source>
         <translation>起動時に Mozcが既定の IME であるか確認する</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1511"/>
+        <location filename="config_dialog.ui" line="1556"/>
         <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
         <translation>ホットキー(Ctrl+Shift)による IME の切り替えを無効化する</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1325"/>
+        <location filename="config_dialog.ui" line="1370"/>
         <source>Default IME</source>
         <translation>既定の IME</translation>
     </message>
     <message>
-        <location filename="config_dialog.ui" line="1550"/>
+        <location filename="config_dialog.ui" line="1595"/>
         <source>Reset to defaults</source>
         <translation>初期値に戻す</translation>
     </message>
@@ -1086,18 +1095,18 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
     </message>
     <message>
         <location filename="config_dialog.cc" line="552"/>
-        <location filename="config_dialog.cc" line="983"/>
+        <location filename="config_dialog.cc" line="985"/>
         <source>Sync is not enabled</source>
         <translation>同期機能：オフ</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="688"/>
-        <location filename="config_dialog.cc" line="710"/>
+        <location filename="config_dialog.cc" line="690"/>
+        <location filename="config_dialog.cc" line="712"/>
         <source>Mozc Converter is not running. Settings were not saved.</source>
         <translation>変換サーバが反応していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="805"/>
+        <location filename="config_dialog.cc" line="807"/>
         <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
  - Personalization data
  - Input history
@@ -1112,39 +1121,79 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
  - 管理者用設定</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="833"/>
+        <location filename="config_dialog.cc" line="835"/>
         <source>Stop Sync</source>
         <translation>同期の解除</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="835"/>
+        <location filename="config_dialog.cc" line="837"/>
         <source>Start Sync</source>
         <translation>同期する</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="851"/>
+        <location filename="config_dialog.cc" line="853"/>
         <source>Stop sync and reset the auth token</source>
         <translation>同期の解除と認証コードのクリア</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="852"/>
+        <location filename="config_dialog.cc" line="854"/>
         <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
 Do you really want to continue?</source>
         <translation>同期の解除と認証コードのクリアを行います。同期を再開するには、新しい認証コードを取得する必要があります。
 実行しますか？</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="936"/>
+        <location filename="config_dialog.cc" line="938"/>
         <source>Not synced yet</source>
         <translation>同期されていません</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="940"/>
+        <location filename="config_dialog.cc" line="942"/>
         <source>Last synced time: </source>
         <translation>最終同期時刻: </translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="995"/>
+        <location filename="config_dialog.cc" line="1000"/>
+        <source>Authorization failed.</source>
+        <translation>認証に失敗しました。</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1003"/>
+        <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
+        <translation>単語数の上限を超えたため同期用辞書をセーブできません。</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1007"/>
+        <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
+        <translation>ファイルサイズの上限を超えたため同期用辞書をセーブできません。</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1011"/>
+        <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
+        <translation>同期用辞書の数が上限を超えたため辞書をセーブできません。</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1015"/>
+        <source>Unknown error was found.</source>
+        <translation>未知のエラーです。</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1028"/>
+        <source>Authorization error</source>
+        <translation>認証失敗</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1033"/>
+        <source>Dictionary sync error</source>
+        <translation>辞書同期エラー</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1036"/>
+        <source>Unknown sync error</source>
+        <translation>未知の同期エラー</translation>
+    </message>
+    <message>
+        <location filename="config_dialog.cc" line="1049"/>
         <source>You are trying to clear all the data in the sync server.
 Do you really want to continue?</source>
         <translation>Google サーバー上の同期データを全て消去します。
@@ -1159,12 +1208,12 @@ Do you really want to continue?</source>
         <translation type="obsolete">同期失敗</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="980"/>
+        <location filename="config_dialog.cc" line="982"/>
         <source>During synchronization</source>
         <translation>同期中です</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="994"/>
+        <location filename="config_dialog.cc" line="1048"/>
         <source>Clear all sync data in Google servers</source>
         <translation>Google サーバー上の同期データを全て消去する</translation>
     </message>
@@ -1173,13 +1222,13 @@ Do you really want to continue?</source>
         <location filename="config_dialog.cc" line="365"/>
         <location filename="config_dialog.cc" line="379"/>
         <location filename="config_dialog.cc" line="387"/>
-        <location filename="config_dialog.cc" line="673"/>
-        <location filename="config_dialog.cc" line="687"/>
-        <location filename="config_dialog.cc" line="697"/>
-        <location filename="config_dialog.cc" line="709"/>
-        <location filename="config_dialog.cc" line="719"/>
-        <location filename="config_dialog.cc" line="731"/>
-        <location filename="config_dialog.cc" line="804"/>
+        <location filename="config_dialog.cc" line="675"/>
+        <location filename="config_dialog.cc" line="689"/>
+        <location filename="config_dialog.cc" line="699"/>
+        <location filename="config_dialog.cc" line="711"/>
+        <location filename="config_dialog.cc" line="721"/>
+        <location filename="config_dialog.cc" line="733"/>
+        <location filename="config_dialog.cc" line="806"/>
         <source>Mozc settings</source>
         <translation>Mozc プロパティ</translation>
     </message>
@@ -1204,22 +1253,22 @@ Do you really want to continue?</source>
         <translation>設定の反映に失敗しました</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="674"/>
+        <location filename="config_dialog.cc" line="676"/>
         <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
         <translation>学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="732"/>
+        <location filename="config_dialog.cc" line="734"/>
         <source>Mozc Converter is not running. Operation was not executed.</source>
         <translation>Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="698"/>
+        <location filename="config_dialog.cc" line="700"/>
         <source>Do you want to clear all history data?</source>
         <translation>すべての入力履歴が削除されます。実行しますか？</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="720"/>
+        <location filename="config_dialog.cc" line="722"/>
         <source>Do you want to clear unused history data?</source>
         <translation>サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
     </message>
@@ -1466,20 +1515,92 @@ Do you really want to continue?</source>
 <context>
     <name>mozc::gui::WebServiceInfolistEditorDialog</name>
     <message>
+        <location filename="webservice_infolist_editor.cc" line="99"/>
         <source>New entry</source>
-        <translation type="obsolete">新しいエントリー</translation>
+        <translation type="unfinished">新しいエントリー</translation>
     </message>
     <message>
+        <location filename="webservice_infolist_editor.cc" line="101"/>
         <source>Remove selected entries</source>
-        <translation type="obsolete">選択されたエントリーを削除</translation>
+        <translation type="unfinished">選択されたエントリーを削除</translation>
     </message>
     <message>
+        <location filename="webservice_infolist_editor.cc" line="104"/>
         <source>Import from file...</source>
-        <translation type="obsolete">インポート...</translation>
+        <translation type="unfinished">インポート...</translation>
     </message>
     <message>
+        <location filename="webservice_infolist_editor.cc" line="106"/>
         <source>Export to file...</source>
-        <translation type="obsolete">エクスポート...</translation>
+        <translation type="unfinished">エクスポート...</translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="109"/>
+        <source>Help...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="111"/>
+        <source>Mozc Web Service Usage Dictionary table editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="123"/>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="123"/>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="124"/>
+        <source>Format type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="124"/>
+        <source>Xpath/Jsonpath</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="188"/>
+        <source>Enter name of Web service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="189"/>
+        <source>Enter URL for of Web service.
+&quot;%s&quot; is expanded to the candidate string.
+&quot;%r&quot; is expanded to the all preedit string.
+
+Example:   http://api.example.com/keyword/%s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="193"/>
+        <source>Select format type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="194"/>
+        <source>Enter Xpath or Jsonpath.
+This query is used for extracting the content from URL.
+
+Example of Xpath:   //content/node
+Example of Jsonpath:   $.content.node</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="231"/>
+        <source>Mozc settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="webservice_infolist_editor.cc" line="232"/>
+        <source>You can&apos;t have more than %1 entries</source>
+        <translation type="unfinished">%1 個以上のエントリーは登録できません</translation>
     </message>
     <message>
         <source>Do you want to overwrite the current roman table?</source>
