@@ -1,4 +1,4 @@
-// Copyright 2010-2011, Google Inc.
+// Copyright 2010-2012, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@
 #include <string>
 #include <vector>
 #include "base/base.h"
-#include "base/config_file_stream.h"
+#include "base/file_stream.h"
 #include "base/util.h"
 #include "session/commands.pb.h"
 
@@ -263,7 +263,8 @@ void GenericTableEditorDialog::Export() {
 
   const QString filename =
       QFileDialog::getSaveFileName(this, tr("export to file"),
-                                   QDir::homePath());
+          QDir::homePath() + QDir::separator() +
+          QString(GetDefaultFilename().c_str()));
   if (filename.isEmpty()) {
     return;
   }
