@@ -14,6 +14,34 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FindDialog</name>
+    <message>
+        <location filename="find_dialog.ui" line="26"/>
+        <source>Mozc Dictionary Find Dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="find_dialog.ui" line="37"/>
+        <source>Reading or Word:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="find_dialog.ui" line="54"/>
+        <source>Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="find_dialog.ui" line="61"/>
+        <source>Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="find_dialog.ui" line="68"/>
+        <source>Cacnel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ImportDialog</name>
     <message>
@@ -50,7 +78,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dictionary_tool.cc" line="232"/>
+        <location filename="dictionary_tool.cc" line="233"/>
         <source>Importing new words...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -58,297 +86,310 @@
 <context>
     <name>mozc::gui::DictionaryTool</name>
     <message>
-        <location filename="dictionary_tool.cc" line="258"/>
+        <location filename="dictionary_tool.cc" line="260"/>
         <source>Mozc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="276"/>
+        <location filename="dictionary_tool.cc" line="285"/>
         <source>Another process is accessing the user dictionary file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="340"/>
+        <location filename="dictionary_tool.cc" line="349"/>
         <source>Reading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="340"/>
+        <location filename="dictionary_tool.cc" line="349"/>
         <source>Word</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="341"/>
+        <location filename="dictionary_tool.cc" line="350"/>
         <source>Comment</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="374"/>
+        <location filename="dictionary_tool.cc" line="383"/>
         <source>New dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1169"/>
+        <location filename="dictionary_tool.cc" line="1178"/>
         <source>Rename...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1170"/>
+        <location filename="dictionary_tool.cc" line="1179"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="379"/>
+        <location filename="dictionary_tool.cc" line="389"/>
         <source>Import as new dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="381"/>
+        <location filename="dictionary_tool.cc" line="391"/>
         <source>Import to current dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="455"/>
+        <location filename="dictionary_tool.cc" line="464"/>
         <source>User Dictionary 1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="619"/>
-        <location filename="dictionary_tool.cc" line="695"/>
+        <location filename="dictionary_tool.cc" line="628"/>
+        <location filename="dictionary_tool.cc" line="704"/>
         <source>You can&apos;t have more than %1 dictionaries.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="624"/>
+        <location filename="dictionary_tool.cc" line="633"/>
         <source>Name of the new dictionary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="638"/>
-        <location filename="dictionary_tool.cc" line="667"/>
-        <location filename="dictionary_tool.cc" line="717"/>
-        <location filename="dictionary_tool.cc" line="867"/>
-        <location filename="dictionary_tool.cc" line="909"/>
+        <location filename="dictionary_tool.cc" line="647"/>
+        <location filename="dictionary_tool.cc" line="676"/>
+        <location filename="dictionary_tool.cc" line="726"/>
+        <location filename="dictionary_tool.cc" line="876"/>
+        <location filename="dictionary_tool.cc" line="918"/>
         <source>No dictionary is selected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="644"/>
+        <location filename="dictionary_tool.cc" line="653"/>
         <source>Do you want to delete %1?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="673"/>
+        <location filename="dictionary_tool.cc" line="682"/>
         <source>New name of the dictionary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1296"/>
+        <location filename="dictionary_tool.cc" line="1305"/>
         <source>Dictionary name is empty.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1301"/>
+        <location filename="dictionary_tool.cc" line="1310"/>
         <source>Dictionary name is too long.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1291"/>
+        <location filename="dictionary_tool.cc" line="1300"/>
         <source>An invalid character is included in the dictionary name.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="292"/>
+        <location filename="dictionary_tool.cc" line="301"/>
         <source>Add</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="382"/>
+        <location filename="dictionary_tool.cc" line="392"/>
         <source>Export current dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="914"/>
+        <location filename="dictionary_tool.cc" line="923"/>
         <source>Export dictionary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="293"/>
+        <location filename="dictionary_tool.cc" line="302"/>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="291"/>
+        <location filename="dictionary_tool.cc" line="300"/>
         <source>Tools</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="341"/>
+        <location filename="dictionary_tool.cc" line="350"/>
         <source>Category</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="376"/>
+        <location filename="dictionary_tool.cc" line="385"/>
         <source>Delete dictionary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="724"/>
-        <location filename="dictionary_tool.cc" line="946"/>
+        <location filename="dictionary_tool.cc" line="733"/>
+        <location filename="dictionary_tool.cc" line="955"/>
         <source>You can&apos;t have more than %1 words in one dictionary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="873"/>
+        <location filename="dictionary_tool.cc" line="882"/>
         <source>All user-registered words in %1 are migrated into the current dictionary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="777"/>
+        <location filename="dictionary_tool.cc" line="786"/>
         <source>Failed to open user dictionary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="915"/>
+        <location filename="dictionary_tool.cc" line="924"/>
         <source>Text Files (*.txt);;All Files (*)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="793"/>
-        <location filename="dictionary_tool.cc" line="923"/>
+        <location filename="dictionary_tool.cc" line="802"/>
+        <location filename="dictionary_tool.cc" line="932"/>
         <source>Can&apos;t open %1.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="375"/>
+        <location filename="dictionary_tool.cc" line="384"/>
         <source>Rename dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="389"/>
+        <location filename="dictionary_tool.cc" line="386"/>
+        <source>Find...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="dictionary_tool.cc" line="399"/>
         <source>Import from %1&apos;s user dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="501"/>
+        <location filename="dictionary_tool.cc" line="510"/>
         <source>Making dangerously large user dictionary file. If the dictionary file turns out to be larger than 256Mbyte, the dictionary loader skips to handle all the words to prevent the converter from being halted.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="581"/>
+        <location filename="dictionary_tool.cc" line="590"/>
         <source>Updating the current view data...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="748"/>
+        <location filename="dictionary_tool.cc" line="757"/>
         <source>%1 entries are imported to %2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="754"/>
+        <location filename="dictionary_tool.cc" line="763"/>
         <source>You have imported a file in an invalid or unsupported file format.
 
 Please check the file format. ATOK11 or older format is not supported by Mozc.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="763"/>
+        <location filename="dictionary_tool.cc" line="772"/>
         <source>%1 doesn&apos;t have enough space to import all words in the file. First %2 entries are imported.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="770"/>
+        <location filename="dictionary_tool.cc" line="779"/>
         <source>%1 entries are imported to %2.
 
 Some imported words were not recognized by %3. Please check the original import file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="858"/>
+        <location filename="dictionary_tool.cc" line="867"/>
         <source>Microsoft IME dictioanry import function doesn&apos;t work on UAC-elevated process.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="936"/>
+        <location filename="dictionary_tool.cc" line="945"/>
         <source>Dictionary export finished.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="984"/>
+        <location filename="dictionary_tool.cc" line="993"/>
         <source>Do you want to delete this word?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="986"/>
+        <location filename="dictionary_tool.cc" line="995"/>
         <source>Do you want to delete the selected words?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1000"/>
+        <location filename="dictionary_tool.cc" line="1009"/>
         <source>Deleting the selected words...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1051"/>
+        <location filename="dictionary_tool.cc" line="1060"/>
         <source>New comment</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1083"/>
+        <location filename="dictionary_tool.cc" line="1092"/>
         <source>An invalid character is included in the reading.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1116"/>
+        <location filename="dictionary_tool.cc" line="1125"/>
         <source>Add a word</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1121"/>
+        <location filename="dictionary_tool.cc" line="1130"/>
         <source>Delete this word</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1128"/>
+        <location filename="dictionary_tool.cc" line="1137"/>
         <source>Delete the selected words</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1136"/>
+        <location filename="dictionary_tool.cc" line="1145"/>
         <source>Change category to</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1144"/>
+        <location filename="dictionary_tool.cc" line="1153"/>
         <source>Edit comment</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1171"/>
+        <location filename="dictionary_tool.cc" line="1180"/>
         <source>Import to this dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1172"/>
+        <location filename="dictionary_tool.cc" line="1181"/>
         <source>Export this dictionary...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1306"/>
+        <location filename="dictionary_tool.cc" line="1315"/>
         <source>Dictionary already exists.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1311"/>
+        <location filename="dictionary_tool.cc" line="1320"/>
         <source>A fatal error occurred.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dictionary_tool.cc" line="1423"/>
+        <location filename="dictionary_tool.cc" line="1432"/>
         <source>%1: %2 entries</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>mozc::gui::FindDialog</name>
+    <message>
+        <location filename="find_dialog.cc" line="127"/>
+        <source>Cannot find pattern %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>mozc::gui::ImportDialog</name>
     <message>
