@@ -1,4 +1,4 @@
-// Copyright 2010-2011, Google Inc.
+// Copyright 2010-2012, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
 #ifndef MOZC_NET_HTTP_CLIENT_H_
 #define MOZC_NET_HTTP_CLIENT_H_
 
-#include <iomanip>
+#include <ostream>
 #include <string>
 #include <vector>
 
