@@ -1,4 +1,4 @@
-// Copyright 2010-2011, Google Inc.
+// Copyright 2010-2012, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,7 @@
 #include <string>
 
 #include "base/util.h"
-#include "session/config_handler.h"
+#include "config/config_handler.h"
 #include "session/key_event_normalizer.h"
 #include "session/key_parser.h"
 #include "session/internal/keymap.h"
