@@ -1,4 +1,4 @@
-// Copyright 2010-2011, Google Inc.
+// Copyright 2010-2012, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -46,14 +46,14 @@ TEST(ImeContextTest, DefaultValues) {
   EXPECT_EQ(0, context.create_time());
   EXPECT_EQ(0, context.last_command_time());
 
-  EXPECT_TRUE(NULL == context.mutable_composer());
+  // Don't access composer().
+  // Before using composer, set_composer() must be called with non-null-value.
+
   EXPECT_TRUE(NULL == context.mutable_converter());
 
   EXPECT_EQ(ImeContext::NONE, context.state());
 
   EXPECT_TRUE(context.transform_table().empty());
-
-  EXPECT_EQ("", context.initial_composition());
 }
 
 TEST(ImeContextTest, BasicTest) {
@@ -91,11 +91,6 @@ TEST(ImeContextTest, BasicTest) {
   context.mutable_output()->set_id(1414);
   EXPECT_EQ(1414, context.output().id());
 
-  // "家"
-  const string house = "\xE5\xAE\xB6";
-  context.set_initial_composition(house);
-  EXPECT_EQ(house, context.initial_composition());
-
   // Get/Set keymap
   context.set_keymap(config::Config::ATOK);
   EXPECT_EQ(config::Config::ATOK, context.keymap());
@@ -171,9 +166,10 @@ TEST(ImeContextTest, CopyContext) {
     source.set_state(ImeContext::CONVERSION);
     source.mutable_composer()->InsertCharacter("a");
     source.mutable_composer()->InsertCharacter("n");
-    source.mutable_converter()->Convert(&source.composer());
+    source.mutable_converter()->Convert(source.composer());
     // "早い"
-    source.set_initial_composition("\xE6\x97\xA9\xE3\x81\x84");
+    const string &kQuick = "\xE6\x97\xA9\xE3\x81\x84";
+    source.mutable_composer()->set_source_text(kQuick);
 
     string composition;
     source.composer().GetQueryForConversion(&composition);
@@ -181,7 +177,7 @@ TEST(ImeContextTest, CopyContext) {
     EXPECT_EQ("\xE3\x81\x82\xE3\x82\x93", composition);
 
     commands::Output output;
-    source.converter().FillOutput(&output);
+    source.converter().FillOutput(source.composer(), &output);
     EXPECT_EQ(1, output.preedit().segment_size());
     // "庵"
     EXPECT_EQ("\xE5\xBA\xB5", output.preedit().segment(0).value());
@@ -194,13 +190,12 @@ TEST(ImeContextTest, CopyContext) {
     EXPECT_EQ("\xE3\x81\x82\xE3\x82\x93", composition);
 
     output.Clear();
-    destination.converter().FillOutput(&output);
+    destination.converter().FillOutput(source.composer(), &output);
     EXPECT_EQ(1, output.preedit().segment_size());
     // "庵"
     EXPECT_EQ("\xE5\xBA\xB5", output.preedit().segment(0).value());
 
-    // "早い"
-    EXPECT_EQ("\xE6\x97\xA9\xE3\x81\x84", destination.initial_composition());
+    EXPECT_EQ(kQuick, destination.composer().source_text());
   }
 }
 
